==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebContentPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescription } from "./WebContentPaneDescription";
/**
 * @hidden
 */
var WebContentPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebContentPaneDescriptionMetadata, _super);
    function WebContentPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebContentPaneDescriptionMetadata.b = function (a) {
        if (WebContentPaneDescriptionMetadata.a == null) {
            WebContentPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebContentPaneDescriptionMetadata.c(WebContentPaneDescriptionMetadata.a);
        }
        if (a.g(WebContentPaneDescriptionMetadata.a)) {
            return;
        }
        a.s(WebContentPaneDescriptionMetadata.a);
    };
    WebContentPaneDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ContentPane");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("ContentId", "String");
        a.item("Header", "String");
        a.item("HeaderId", "String");
        a.item("TabHeaderId", "String");
        a.item("UnpinnedHeaderId", "String");
        a.item("FloatingHeaderId", "String");
        a.item("Size", "Number:double");
        a.item("AllowClose", "Boolean");
        a.item("AllowMaximize", "Boolean");
        a.item("AllowPinning", "Boolean");
        a.item("AllowDocking", "Boolean");
        a.item("AllowFloating", "Boolean");
        a.item("UnpinnedSize", "Number:double");
        a.item("IsPinned", "Boolean");
        a.item("UnpinnedLocation", "ExportedType:string:ContentPaneUnpinnedLocation");
        a.item("UnpinnedLocation@names", "Top;Bottom;Left;Right");
        a.item("Hidden", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("DocumentOnly", "Boolean");
    };
    WebContentPaneDescriptionMetadata.d = function (a) {
        WebContentPaneDescriptionMetadata.b(a);
        a.u("WebContentPane", function () { return new WebContentPaneDescription(); });
        a.t("WebContentPane", WebContentPaneDescriptionMetadata.a);
    };
    WebContentPaneDescriptionMetadata.$t = markType(WebContentPaneDescriptionMetadata, 'WebContentPaneDescriptionMetadata');
    WebContentPaneDescriptionMetadata.a = null;
    return WebContentPaneDescriptionMetadata;
}(Base));
export { WebContentPaneDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebContentPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebContentPaneDescription } from "./WebContentPaneDescription";
/**
 * @hidden
 */
var WebContentPaneDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebContentPaneDescriptionMetadata, _super);
    function WebContentPaneDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebContentPaneDescriptionMetadata.b = function (a) {
        if (WebContentPaneDescriptionMetadata.a == null) {
            WebContentPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebContentPaneDescriptionMetadata.c(WebContentPaneDescriptionMetadata.a);
        }
        if (a.j(WebContentPaneDescriptionMetadata.a)) {
            return;
        }
        a.y(WebContentPaneDescriptionMetadata.a);
    };
    WebContentPaneDescriptionMetadata.c = function (a) {
        WebDockManagerPaneDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ContentPane");
        a.item("Id", "String");
        a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
        a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
        a.item("ContentId", "String");
        a.item("Header", "String");
        a.item("HeaderId", "String");
        a.item("TabHeaderId", "String");
        a.item("UnpinnedHeaderId", "String");
        a.item("FloatingHeaderId", "String");
        a.item("Size", "Number:double");
        a.item("AllowClose", "Boolean");
        a.item("AllowMaximize", "Boolean");
        a.item("AllowPinning", "Boolean");
        a.item("AllowDocking", "Boolean");
        a.item("AllowFloating", "Boolean");
        a.item("UnpinnedSize", "Number:double");
        a.item("IsPinned", "Boolean");
        a.item("UnpinnedLocation", "ExportedType:string:ContentPaneUnpinnedLocation");
        a.item("UnpinnedLocation@names", "Top;Bottom;Left;Right");
        a.item("Hidden", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("DocumentOnly", "Boolean");
    };
    WebContentPaneDescriptionMetadata.d = function (a) {
        WebContentPaneDescriptionMetadata.b(a);
        a.aa("WebContentPane", function () { return new WebContentPaneDescription(); });
        a.z("WebContentPane", WebContentPaneDescriptionMetadata.a);
    };
    WebContentPaneDescriptionMetadata.$t = markType(WebContentPaneDescriptionMetadata, 'WebContentPaneDescriptionMetadata');
    WebContentPaneDescriptionMetadata.a = null;
    return WebContentPaneDescriptionMetadata;
}(Base));
export { WebContentPaneDescriptionMetadata };
